@@ -6,6 +6,10 @@ pub enum Error {
 	/// Error that may occur while I/O operations.
 	#[error("IO error: `{0}`")]
 	IoError(#[from] std::io::Error),
+	/// Error that may occur when attempting to interpret a sequence of u8 as a
+	/// string.
+	#[error("UTF-8 error: `{0}`")]
+	Utf8Error(#[from] std::str::Utf8Error),
 	/// Error variant that represents errors coming out of libgit2.
 	#[error("Git error: `{0}`")]
 	GitError(#[from] git2::Error),
@@ -22,12 +26,24 @@ pub enum Error {
 	/// Error that may occur while generating changelog.
 	#[error("Changelog error: `{0}`")]
 	ChangelogError(String),
-	/// Error that may occur while template operations such as parse and render.
+	/// Error that may occur while parsing the template.
+	#[error("Template parse error:\n{0}")]
+	TemplateParseError(String),
+	/// Error that may occur while rendering the template.
+	#[error("Template render error:\n{0}")]
+	TemplateRenderError(String),
+	/// Error that may occur during more general template operations.
 	#[error("Template error: `{0}`")]
 	TemplateError(#[from] tera::Error),
 	/// Error that may occur while parsing the command line arguments.
 	#[error("Argument error: `{0}`")]
 	ArgumentError(String),
+	/// Error that may occur while extracting the embedded content.
+	#[error("Embedded error: `{0}`")]
+	EmbeddedError(String),
+	/// Errors that may occur when deserializing types from TOML format.
+	#[error("Cannot parse TOML: `{0}`")]
+	DeserializeError(#[from] toml::de::Error),
 }
 
 /// Result type of the core library.
